@@ -5,18 +5,18 @@
  */
 RcppExport SEXP testFFT() {
     BEGIN_RCPP
-    int N = 128;
+    int N = 128, fac = 1;
     double u0 = -1.5, du = 3.0/N, dx=2*3.14159265/N/du, x0 = -N*dx/2;
     std::vector<double> u(N);
     std::vector<double> x(N);
     std::vector<std::complex<double> > f(N); // f(u) = 1 on [-.5,.5]
-    int fac = 1;
+    double funcval = 0;
     for(int i=0; i < N; ++i) {
 	u[i] = u0 + i*du;
 	x[i] = x0 + i*dx;
-	f[i].real() = fac * ((u[i] >= -0.5 && u[i] < 0.5) ? 1.0 : 0.0);
+	funcval = (u[i] >= -0.5 && u[i] < 0.5) ? 1.0 : 0.0;
+	f[i] = std::complex<double>(fac*funcval, 0);
 	fac = -fac;
-	f[i].imag() = 0.0;
     }
     std::vector<std::complex<double> > cresult = cxxPack::fft1d(f);
     std::vector<double> result(N);
